"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const graphql_1 = require("graphql");
const common_1 = require("@graphql-toolkit/common");
function stripBOM(content) {
    content = content.toString();
    // Remove byte order marker. This catches EF BB BF (the UTF-8 BOM)
    // because the buffer-to-string conversion in `fs.readFileSync()`
    // translates it to FEFF, the UTF-16 BOM.
    if (content.charCodeAt(0) === 0xfeff) {
        content = content.slice(1);
    }
    return content;
}
function parseBOM(content) {
    return JSON.parse(stripBOM(content));
}
class JsonFileLoader {
    loaderId() {
        return 'json-file';
    }
    async canLoad(pointer, options) {
        const extension = path_1.extname(pointer).toLowerCase();
        return extension === '.json';
    }
    async load(pointer, options) {
        return new Promise((resolve, reject) => {
            const { existsSync, readFileSync } = eval(`require('fs')`);
            const normalizedFilepath = path_1.isAbsolute(pointer) ? pointer : path_1.resolve(options.cwd || process.cwd(), pointer);
            if (existsSync(normalizedFilepath)) {
                try {
                    const fileContent = readFileSync(normalizedFilepath, 'utf8');
                    if (!fileContent) {
                        reject(`Unable to read local introspection file: ${normalizedFilepath}`);
                    }
                    let introspection = parseBOM(fileContent);
                    if (introspection['data']) {
                        introspection = introspection['data'];
                    }
                    if (!introspection.__schema) {
                        throw new Error('Invalid schema provided!');
                    }
                    const asSchema = graphql_1.buildClientSchema(introspection);
                    const printed = common_1.printSchemaWithDirectives(asSchema);
                    resolve({
                        location: pointer,
                        document: graphql_1.parse(printed),
                    });
                }
                catch (e) {
                    reject(e);
                }
            }
            else {
                reject(`Unable to locate local introspection file: ${normalizedFilepath}`);
            }
        });
    }
}
exports.JsonFileLoader = JsonFileLoader;
//# sourceMappingURL=load-from-json-file.js.map