import { extname, isAbsolute, resolve as resolvePath } from 'path';
import { buildClientSchema, parse } from 'graphql';
import { printSchemaWithDirectives } from '@graphql-toolkit/common';
function stripBOM(content) {
    content = content.toString();
    // Remove byte order marker. This catches EF BB BF (the UTF-8 BOM)
    // because the buffer-to-string conversion in `fs.readFileSync()`
    // translates it to FEFF, the UTF-16 BOM.
    if (content.charCodeAt(0) === 0xfeff) {
        content = content.slice(1);
    }
    return content;
}
function parseBOM(content) {
    return JSON.parse(stripBOM(content));
}
export class JsonFileLoader {
    loaderId() {
        return 'json-file';
    }
    async canLoad(pointer, options) {
        const extension = extname(pointer).toLowerCase();
        return extension === '.json';
    }
    async load(pointer, options) {
        return new Promise((resolve, reject) => {
            const { existsSync, readFileSync } = eval(`require('fs')`);
            const normalizedFilepath = isAbsolute(pointer) ? pointer : resolvePath(options.cwd || process.cwd(), pointer);
            if (existsSync(normalizedFilepath)) {
                try {
                    const fileContent = readFileSync(normalizedFilepath, 'utf8');
                    if (!fileContent) {
                        reject(`Unable to read local introspection file: ${normalizedFilepath}`);
                    }
                    let introspection = parseBOM(fileContent);
                    if (introspection['data']) {
                        introspection = introspection['data'];
                    }
                    if (!introspection.__schema) {
                        throw new Error('Invalid schema provided!');
                    }
                    const asSchema = buildClientSchema(introspection);
                    const printed = printSchemaWithDirectives(asSchema);
                    resolve({
                        location: pointer,
                        document: parse(printed),
                    });
                }
                catch (e) {
                    reject(e);
                }
            }
            else {
                reject(`Unable to locate local introspection file: ${normalizedFilepath}`);
            }
        });
    }
}
//# sourceMappingURL=load-from-json-file.js.map